@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2006 Tim Riker
+ * Copyright (c) 1993-2010 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -13,6 +13,9 @@
 /* interface header */
 #include "HelpMenu.h"
 
+// system headers
+#include <string.h>
+
 /* common implementation headers */
 #include "KeyManager.h"
 #include "Flag.h"
@@ -558,7 +561,7 @@ Help9Menu::Help9Menu() : HelpMenu("Credits")
   listHUD.push_back(createLabel("", ""));
   listHUD.push_back(createLabel("http://BZFlag.org/", "BZFlag Home Page:"));
   listHUD.push_back(createLabel("", ""));
-  listHUD.push_back(createLabel("Tim Riker", "Copyright (c) 1993 - 2006"));
+  listHUD.push_back(createLabel("Tim Riker", "Copyright (c) 1993 - 2008"));
 }
 
 float Help9Menu::getLeftSide(int _width, int _height)
