@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2006 Tim Riker
+ * Copyright (c) 1993-2010 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -38,6 +38,7 @@
 /* common headers */
 #include "Address.h"
 #include "BZDBCache.h"
+#include "BZDBLocal.h"
 #include "BundleMgr.h"
 #include "BzfMedia.h"
 #include "BzfVisual.h"
@@ -154,8 +155,11 @@ static void		setVisual(BzfVisual* visual)
   }
 
   // optional
+  visual->setStencil(4);
 #if defined(DEBUG_RENDERING)
   visual->setStencil(4);
+#else
+  visual->setStencil(1);
 #endif
   if (BZDB.isTrue("multisample"))
     visual->setMultisample(4);
@@ -231,10 +235,11 @@ static void		parse(int argc, char** argv)
     } else if ((strcmp(argv[i], "-dir") == 0) ||
 	       (strcmp(argv[i], "-directory") == 0)) {
       checkArgc(i, argc, argv[i]);
-      if (strlen(argv[i]) == 0)
+      if (strlen(argv[i]) == 0) {
 	BZDB.unset("directory");
-	  else
-		BZDB.set("directory", argv[i]);
+      } else {
+	BZDB.set("directory", argv[i]);
+      }
     } else if (strcmp(argv[i], "-e") == 0 || strcmp(argv[i], "-echo") == 0) {
       echoToConsole = true;
     } else if (strcmp(argv[i], "-ea") == 0 || strcmp(argv[i], "-echoAnsi") == 0) {
@@ -654,6 +659,33 @@ int			main(int argc, char** argv)
     exit(0);
   }
 
+#if defined(_WIN32)
+  {
+    /* write HKEY_CURRENT_USER\Software\BZFlag\CurrentRunningPath with the
+     * current path.  this lets Xfire know that this bzflag.exe running from
+     * here really is bzflag, not some imposter.
+     * since it may be useful to someone else, it's not protected by USE_XFIRE
+     */
+
+    // get our path
+    char temppath[MAX_PATH], temppath2[MAX_PATH];
+    char tempdrive[10];
+    GetModuleFileName(NULL, temppath, MAX_PATH);
+    // strip filename/extension
+    _splitpath(temppath, tempdrive, temppath2, NULL, NULL);
+    _makepath(temppath, tempdrive, temppath2, NULL, NULL);
+
+    // write the registry key in question
+    HKEY key = NULL;
+    if (RegCreateKeyEx(HKEY_CURRENT_USER, "Software\\BZFlag",
+	0, NULL, REG_OPTION_VOLATILE, KEY_ALL_ACCESS, NULL,
+	&key, NULL) == ERROR_SUCCESS) {
+      RegSetValueEx(key, "CurrentRunningPath", 0, REG_SZ, (LPBYTE)temppath,
+		   (DWORD)strlen(temppath));
+    }
+  }
+#endif
+
   createCacheSignature();
 
   // initialize global objects and classes
@@ -671,6 +703,8 @@ int			main(int argc, char** argv)
   }
 
   BZDBCache::init();
+  BZDBLOCAL.init();
+
   Flags::init();
 
   if (getenv("BZFLAGID")) {
@@ -780,7 +814,7 @@ int			main(int argc, char** argv)
     // however, if the "__window" setting is enabled, let it through
     if (BZDB.isSet("__window"))
       if (BZDB.isTrue("__window"))
-        BZDB.set("_window", "1");
+	BZDB.set("_window", "1");
   }
 
   // use UDP? yes
@@ -938,17 +972,11 @@ int			main(int argc, char** argv)
 
   // set data directory if user specified
   if (BZDB.isSet("directory")) {
+    /* already specified, so just set/use it */
     PlatformFactory::getMedia()->setMediaDirectory(BZDB.get("directory"));
   } else {
 
-    // !!! fix this stupid check.. GetMacOSXDataPath() is NULL without app bundle.
-
-#if defined(__APPLE__)
-    extern char *GetMacOSXDataPath(void);
-    PlatformFactory::getMedia()->setMediaDirectory(GetMacOSXDataPath());
-    BZDB.set("directory", GetMacOSXDataPath());
-    BZDB.setPersistent("directory", false);
-#elif (defined(_WIN32) || defined(WIN32))
+#if (defined(_WIN32) || defined(WIN32))
     char exePath[MAX_PATH];
     GetModuleFileName(NULL,exePath,MAX_PATH);
     char* last = strrchr(exePath,'\\');
@@ -960,11 +988,18 @@ int			main(int argc, char** argv)
       media->setMediaDirectory(exePath);
 #else
     // It's only checking existence of l10n directory
-    DIR *localedir = opendir("data/l10n/");
-    if (localedir == NULL) {
-      PlatformFactory::getMedia()->setMediaDirectory(INSTALL_DATA_DIR);
-    } else {
+    std::string mediadir = DEFAULT_MEDIA_DIR;
+    mediadir += "/l10n";
+    DIR *localedir = opendir(mediadir.c_str());
+    if (localedir != NULL) {
+      /* found 'data' dir */
+      BzfMedia *media = PlatformFactory::getMedia();
+      if (media)
+	media->setMediaDirectory(DEFAULT_MEDIA_DIR);
       closedir(localedir);
+    } else {
+      /* bah, just set the compile-time path */
+      PlatformFactory::getMedia()->setMediaDirectory(INSTALL_DATA_DIR);
     }
 #endif
   }
@@ -1025,8 +1060,10 @@ int			main(int argc, char** argv)
   // the resolution to use)
   const bool useFullscreen = needsFullscreen();
   if (useFullscreen) {
+#ifndef HAVE_SDL
     // tell window to be fullscreen
-    window->setFullscreen();
+    window->setFullscreen(true);
+#endif
 
     // set the size if one was requested.  this overrides the default
     // size (which is the display or passthrough size).
@@ -1310,6 +1347,18 @@ int			main(int argc, char** argv)
   delete bm;
   Flags::kill();
 
+#if defined(_WIN32)
+  {
+    /* clear HKEY_CURRENT_USER\Software\BZFlag\CurrentRunningPath if it
+     * exists */
+    HKEY key = NULL;
+    if (RegOpenKeyEx(HKEY_CURRENT_USER, "Software\\BZFlag",
+	0, KEY_ALL_ACCESS, &key) == ERROR_SUCCESS) {
+      RegSetValueEx(key, "CurrentRunningPath", 0, REG_SZ, (LPBYTE)"\0", 1);
+    }
+  }
+#endif
+
 #ifdef _WIN32
   // clean up
   WSACleanup();
