@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2006 Tim Riker
+ * Copyright (c) 1993-2010 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -486,22 +486,22 @@ void CollisionManager::load ()
   RayList.count = 0;
 
   // print some statistics
-  DEBUG2 ("ColDet Octree obstacles = %i\n", FullList.count);
+  logDebugMessage(2,"ColDet Octree obstacles = %i\n", FullList.count);
   for (i = 0; i < 3; i++) {
-    DEBUG2 ("  grid extent[%i] = %f, %f\n", i, gridExtents.mins[i],
+    logDebugMessage(2,"  grid extent[%i] = %f, %f\n", i, gridExtents.mins[i],
 					       gridExtents.maxs[i]);
   }
   for (i = 0; i < 3; i++) {
-    DEBUG2 ("  world extent[%i] = %f, %f\n", i, worldExtents.mins[i],
+    logDebugMessage(2,"  world extent[%i] = %f, %f\n", i, worldExtents.mins[i],
 						worldExtents.maxs[i]);
   }
-  DEBUG2 ("ColDet Octree leaf nodes  = %i\n", leafNodes);
-  DEBUG2 ("ColDet Octree total nodes = %i\n", totalNodes);
-  DEBUG2 ("ColDet Octree total elements = %i\n", totalElements);
+  logDebugMessage(2,"ColDet Octree leaf nodes  = %i\n", leafNodes);
+  logDebugMessage(2,"ColDet Octree total nodes = %i\n", totalNodes);
+  logDebugMessage(2,"ColDet Octree total elements = %i\n", totalElements);
 
   // print the timing info
   float elapsed = (float)(TimeKeeper::getCurrent() - startTime);
-  DEBUG2 ("Collision Octree processed in %.3f seconds.\n", elapsed);
+  logDebugMessage(2,"Collision Octree processed in %.3f seconds.\n", elapsed);
 
 
   // setup the split list
@@ -667,7 +667,7 @@ ColDetNode::ColDetNode(unsigned char _depth,
   // return if this is a leaf node
   if (((int)depth >= maxDepth) || (fullList.count <= minElements)) {
     resizeCell();
-    //DEBUG4 ("COLDET LEAF NODE: depth = %d, items = %i\n", depth, count);
+    //logDebugMessage(4, ("COLDET LEAF NODE: depth = %d, items = %i\n", depth, count);
     return;
   }
 
@@ -686,7 +686,7 @@ ColDetNode::ColDetNode(unsigned char _depth,
   free (fullList.list);
   fullList.list = NULL;
 
-  //DEBUG4 ("COLDET BRANCH NODE: depth = %d, children = %i\n", depth, childCount);
+  //logDebugMessage(4, ("COLDET BRANCH NODE: depth = %d, children = %i\n", depth, childCount);
 
   return;
 }
